===============================
ballet primitives and pipelines
===============================

In lieu of a better documentation of the ML primitives and ML pipelines available in Ballet, we just show the JSON annotations. There is no comprehensive reference on the primitive and pipeline format, but see `primitives reference <https://mlbazaar.github.io/MLBlocks/advanced_usage/primitives.html>`__ and `pipelines reference <https://mlbazaar.github.io/MLBlocks/advanced_usage/pipelines.html>`__.

primitives
----------

ballet.engineer_features
^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../ballet/mlprimitives/primitives/ballet.engineer_features.json
   :language: json

ballet.encode_target
^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../ballet/mlprimitives/primitives/ballet.encode_target.json
   :language: json

pipelines
---------

ballet_rf_classifier
^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../ballet/mlprimitives/pipelines/ballet_rf_classifier.json
   :language: json

ballet_rf_regressor
^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../ballet/mlprimitives/pipelines/ballet_rf_regressor.json
   :language: json
